package net.javase.onenet.api;

import cn.hutool.http.ContentType;
import cn.hutool.http.Method;
import net.javase.onenet.config.Config;
import net.javase.onenet.enums.ApiEnum;
import net.javase.onenet.enums.SignMethod;
import net.javase.onenet.model.DataPointQueryModel;
import net.javase.onenet.model.SyncCmdsModel;

/**
 * DataPointApi
 * <p>
 * 数据流API
 *
 * @author Frank
 */
public class DataPointApi {

    /**
     * 查询设备数据点
     *
     * @param config {@link Config}
     * @param model  {@link DataPointQueryModel}
     * @return {@link ApiResponse}
     */
    public static ApiResponse historyDataPoints(Config config, DataPointQueryModel model) {
        return ApiRequest.builder()
                .api(ApiEnum.DATAPOINT_HISTORY.api())
                .method(Method.GET)
                .signMethod(SignMethod.MD5)
                .userid(config.getUserid())
                .query(model.toMap())
                .build()
                .send(config.getAccessKey());
    }

    /**
     * 批量查询产品下设备最新数据点
     *
     * @param config {@link Config}
     * @param model  {@link DataPointQueryModel}
     * @return {@link ApiResponse}
     */
    public static ApiResponse currentDataPoints(Config config, DataPointQueryModel model) {
        return ApiRequest.builder()
                .api(ApiEnum.DATAPOINT_CURRENT.api())
                .method(Method.GET)
                .signMethod(SignMethod.MD5)
                .userid(config.getUserid())
                .query(model.toMap())
                .build()
                .send(config.getAccessKey());
    }

    /**
     * MQTT命令下发
     *
     * @param config {@link Config}
     * @param model  请求参数对象
     * @return {@link ApiResponse}
     */
    public static ApiResponse syncCmds(Config config, SyncCmdsModel model) {
        return ApiRequest.builder()
                .api(ApiEnum.DATAPOINT_SYNCCMDS.api())
                .method(Method.POST)
                .contentType(ContentType.JSON)
                .signMethod(SignMethod.MD5)
                .query(model.toMap())
                .body(model.getArgs())
                .userid(config.getUserid())
                .build()
                .send(config.getAccessKey());
    }
}
