package net.javase.onenet.enums;

import cn.hutool.core.util.StrUtil;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * ApiEnum
 *
 * @author Frank
 */
@Getter
@AllArgsConstructor
public enum ApiEnum {

    // 设备管理
    /**
     * 创建设备
     */
    DEVICE_CREATE("/device/create"),

    /**
     * 设备详情
     */
    DEVICE_DETAIL("/device/detail"),

    /**
     * 更新设备
     */
    DEVICE_UPDATE("/device/update"),

    /**
     * 删除设备
     */
    DEVICE_DELETE("/device/delete"),

    /**
     * 重置设备接入鉴权key
     */
    DEVICE_REST_SECKEY("/device/reset-seckey"),

    /**
     * 设备状态历史变更记录
     */
    DEVICE_STATUS_HISTORY("/device/status-history"),

    /**
     * 设备操作记录查询
     */
    DEVICE_OPERATION_LOG("/device/operation-log"),

    /**
     * 设备服务记录查询
     */
    DEVICE_SERVICE_LOG("/device/service-log"),

    /**
     * 设备事件记录查询
     */
    DEVICE_EVENT_LOG("/device/event-log"),

    /**
     * 设备转移
     */
    DEVICE_MOVE("/device/movedevice"),

    /**
     * 设备分组列表
     */
    DEVICE_GROUP_LIST("/devicegroup/list"),

    /**
     * 设备分组详情
     */
    DEVICE_GROUP_DETAIL("/devicegroup/detail"),

    /**
     * 新建设备分组
     */
    DEVICE_GROUP_CREATE("/devicegroup/create"),

    /**
     * 编辑设备分组
     */
    DEVICE_GROUP_UPDATE("/devicegroup/update"),

    /**
     * 删除设备分组
     */
    DEVICE_GROUP_DELETE("/devicegroup/delete"),

    /**
     * 设备分组-添加设备
     */
    DEVICE_GROUP_ADD_DEVICES("/devicegroup/add-devices"),

    /**
     * 设备分组-删除设备
     */
    DEVICE_GROUP_DEL_DEVICES("/devicegroup/del-devices"),

    /**
     * 设备分组-设备列表
     */
    DEVICE_GROUP_DEVICES("/devicegroup/devices"),


    // 设备文件管理
    /**
     * 账户文件列表查询
     */
    DEVICE_FILE_LIST("/device/file-list"),

    /**
     * 设备文件上传
     */
    DEVICE_FILE_UPLOAD("/device/file-upload"),

    /**
     * 设备文件删除
     */
    DEVICE_FILE_DELETE("/device/file-delete"),

    /**
     * 设备文件下载
     */
    DEVICE_FILE_DOWNLOAD("/device/file-download"),

    /**
     * 账户文件存储空间查询
     */
    DEVICE_FILE_SPACE("/device/file-space"),

    /**
     * 设备文件数量查询
     */
    DEVICE_FILE_DEVICE_COUNT("/device/file-device-count"),

    // 物模型管理
    /**
     * 物模型系统功能点列表
     */
    TSL_QUERY_SYSTEM_THING_MODEL("/thingmodel/query-system-thing-model"),

    /**
     * 物模型查询
     */
    QUERY_THING_MODEL("/thingmodel/query-thing-model"),

    /**
     * 设置设备属性
     */
    SET_DEVICE_PROPERTY("/thingmodel/set-device-property"),

    /**
     * 获取设备属性详情
     */
    QUERY_DEVICE_PROPERTY_DETAIL("/thingmodel/query-device-property-detail"),

    /**
     * 设备属性最新数据查询
     */
    QUERY_DEVICE_PROPERTY("/thingmodel/query-device-property"),

    /**
     * 设备属性记录查询
     */
    QUERY_DEVICE_PROPERTY_HISTORY("/thingmodel/query-device-property-history"),

    /**
     * 设备服务调用
     */
    CALL_SERVICE("/thingmodel/call-service"),

    /**
     * 设备属性期望设置
     */
    SET_DEVICE_DESIRED_PROPERTY("/thingmodel/set-device-desired-property"),

    /**
     * 设备属性期望查询
     */
    QUERY_DEVICE_DESIRED_PROPERTY("/thingmodel/query-device-desired-property"),

    /**
     * 设备属性期望删除
     */
    DELETE_DEVICE_DESIRED_PROPERTY("/thingmodel/delete-device-desired-property"),

    // 数据流使用
    /**
     * 查询设备数据点
     */
    DATAPOINT_HISTORY("/datapoint/history-datapoints"),

    /**
     * 批量查询产品下设备最新数据点
     */
    DATAPOINT_CURRENT("/datapoint/current-datapoints"),

    /**
     * 设备下发命令
     */
    DATAPOINT_SYNCCMDS("/datapoint/synccmds"),

    // LwM2M-即时命令

    /**
     * 获取资源列表
     */
    NBIOT_RESOURCES("/nb-iot/resources"),

    /**
     * 即时命令-资源发现
     */
    NBIOT_DISCOVER("/nb-iot/discover"),

    /**
     * 即时命令-资源订阅
     */
    NBIOT_OBSERVE("/nb-iot/observe"),

    /**
     * 即时命令-读取/写入 设备资源
     */
    NBIOT("/nb-iot"),

    /**
     * 即时命令-设备命令下发
     */
    NBIOT_EXECUTE("/nb-iot/execute"),

    // LwM2M-缓存命令

    /**
     * 缓存命令- 写入/读取 设备资源
     */
    NBIOT_OFFLINE("/nb-iot/offline"),

    /**
     * 缓存命令-设备命令下发
     */
    NBIOT_OFFLINE_EXECUTE("/nb-iot/execute/offline"),

    /**
     * 缓存命令-查询指定设备缓存命令列表
     */
    NBIOT_OFFLINE_HISTORY("/nb-iot/offline/history"),

    /**
     * 缓存命令-查询指定缓存命令详情
     */
    NBIOT_OFFLINE_HISTORY_UUID("/nb-iot/offline/history/{}"),


    /**
     * 缓存命令-取消指定的缓存命令
     */
    NBIOT_OFFLINE_CANCEL_UUID("/nb-iot/offline/cancel/{}"),

    /**
     * 缓存命令-取消设备所有未下发的缓存命令
     */
    NBIOT_OFFLINE_CANCEL_ALL("/nb-iot/offline/cancel/all"),

    /**
     * 缓存命令-全链路日志查询
     */
    NBIOT_OFFLINE_HISTORY_PIECEWISE("/nb-iot/offline/history/{}/piecewise"),

    // LwM2M-DTLS

    /**
     * 查看/更新 指定设备bs_psk信息
     */
    NBIOT_DEVICE_PSK("/nb-iot/device/psk"),

    /**
     * 查看/新增/编辑 指定设备acc_psk信息
     */
    NBIOT_DEVICE_ACCPSK("/nb-iot/device/accpsk"),

    // 工业标识管理

    /**
     * 工业标识管理-设备批量自动注册标识接口
     */
    FUSE_IDENTITY_DEVICE("/fuse-identity-device/batch-auto-regist-device-identity"),

    // LBS位置能力

    /**
     * 基站定位获取最新位置接口
     */
    LBS_LATEST_LOCATION("/fuse-lbs/latest-location"),

    /**
     * 基站定位历史轨迹查询接口
     */
    LBS_GET_TRAIL("/fuse-lbs/get-trail"),

    /**
     * WIFI定位获取最新位置接口
     */
    LBS_LATEST_WIFI_LOCATION("/fuse-lbs/latest-wifi-location"),

    /**
     * WIFI定位历史轨迹查询接口
     */
    LBS_GET_WIFI_TRAIL("/fuse-lbs/get-wifi-trail"),

    // OTA南向

    /**
     * 检测升级任务
     */
    OTA_CHECK("/fuse-ota/{}/{}/check"),

    /**
     * 下载升级包
     */
    OTA_DOWNLOAD("/fuse-ota/{}/{}/{}/download"),

    /**
     * 上报升级状态
     */
    OTA_STATUS("/fuse-ota/{}/{}/{}/status"),

    /**
     * 检测任务状态
     */
    OTA_TID_CHECK("/fuse-ota/{}/{}/{}/check"),

    /**
     * 上报/查看 版本号
     */
    OTA_VERSION("/fuse-ota/{}/{}/version"),

    // 语音能力

    /**
     * 语音通知接口
     */
    VOICE_NOTIFY("/fuse-voice/voiceNotify"),

    ;

    /**
     * api url
     */
    private final String url;

    /**
     * 获取api, 用于处理带占位符url参数的api
     *
     * @param params 参数
     * @return 完整url
     */
    public String api(Object... params) {
        return StrUtil.format(url, params);
    }

}
