package net.javase.onenet.model;

import lombok.Builder;
import lombok.Getter;
import lombok.Setter;
import net.javase.onenet.annotation.ApiParam;
import net.javase.onenet.model.base.BaseModel;

import java.util.Map;

/**
 * NbInstantModel
 *
 * @author Frank
 */
@Getter
@Setter
@Builder
public class NbInstantModel extends BaseModel {

    /**
     * nbiot设备的身份码，必填
     */
    @ApiParam(isQuery = true)
    private String imei;

    /**
     * true为取消订阅，false为订阅，必填
     */
    @ApiParam(isQuery = true)
    private Boolean cancel;

    /**
     * nbiot设备的object id , 对应到平台模型中为数据流id，必填
     */
    @ApiParam(name = "obj_id", isQuery = true)
    private Integer objId;

    /**
     * 设备object下具体一个instance的id ，对应到平台模型中数据点key值的一部分，选填
     */
    @ApiParam(name = "obj_inst_id", isQuery = true)
    private Integer objInstId;

    /**
     * nbiot设备的资源id，选填
     */
    @ApiParam(name = "res_id", isQuery = true)
    private Integer resId;

    /**
     * 上传数据的最小时间间隔，默认为0，此时有数据就上传
     */
    @ApiParam(isQuery = true)
    private Integer pmin;

    /**
     * 上传数据的最大时间间隔
     */
    @ApiParam(isQuery = true)
    private Integer pmax;

    /**
     * 当数据值大于该值时上传
     */
    @ApiParam(isQuery = true)
    private Double gt;

    /**
     * 当数据值小于该值时上传
     */
    @ApiParam(isQuery = true)
    private Double lt;

    /**
     * 当前后两个数据点值相差大于或者等于该值时
     */
    @ApiParam(isQuery = true)
    private Double st;

    /**
     * 超时时间,可选,默认25秒，取值范围[5,40]
     */
    @ApiParam(isQuery = true)
    private Integer timeout;

    /**
     * write模式，只能为1或者2
     */
    @ApiParam(isQuery = true)
    private Integer mode;

    /**
     * 写设备资源的json数组,通过HTTP BODY提交，大小限制2k
     */
    private Map<String, Object> data;

    /**
     * 命令字符串，大小限制2KB
     */
    private String args;

}
