package net.javase.onenet.model;

import lombok.Builder;
import lombok.Getter;
import lombok.Setter;
import net.javase.onenet.annotation.ApiParam;
import net.javase.onenet.model.base.BaseModel;

import java.util.Map;

/**
 * NbOfflineModel 缓存命令
 *
 * @author Frank
 */
@Getter
@Setter
@Builder
public class NbOfflineModel extends BaseModel {

    /**
     * nbiot设备的身份码，必填
     */
    @ApiParam(isQuery = true)
    private String imei;

    /**
     * nbiot设备的object id , 对应到平台模型中为数据流id，必填
     */
    @ApiParam(name = "obj_id", isQuery = true)
    private Integer objId;

    /**
     * 设备object下具体一个instance的id ，对应到平台模型中数据点key值的一部分，选填
     */
    @ApiParam(name = "obj_inst_id", isQuery = true)
    private Integer objInstId;

    /**
     * nbiot设备的资源id，选填
     */
    @ApiParam(name = "res_id", isQuery = true)
    private Integer resId;

    /**
     * 1：直接替换；2：局部更新
     */
    @ApiParam(isQuery = true)
    private Integer mode;

    /**
     * 命令开始生效时间，可选（不填时默认为OneNET当前时间），填写必须大于OneNET服务器的当前时间
     */
    @ApiParam(name = "valid_time", isQuery = true)
    private String validTime;

    /**
     * 命令过期时间，必须大于valid_time
     */
    @ApiParam(name = "expired_time", isQuery = true)
    private String expiredTime;

    /**
     * 表示失败重试次数（等待下一次设备update或者上线），可选（不填时默认为3），填写时必须在[0, 10]之间
     */
    @ApiParam(isQuery = true)
    private Integer retry;

    /**
     * 命令触发的上行消息类型，填写时必须在[1,7]之间；不填写默认为7
     */
    @ApiParam(name = "trigger_msg", isQuery = true)
    private Integer triggerMsg;

    /**
     * 命令触发的上行消息类型，填写时必须在[1,7]之间；不填写默认为7
     */
    @ApiParam(isQuery = true)
    private Boolean bin2hex;

    /**
     * true/false，默认false，如果bin2hex为true，资源类型为Opaque的值将被转换成十六进制字符串返回
     */
    @ApiParam(isQuery = true)
    private Integer timeout;

    /**
     * 写设备资源的json，大小限制2k
     */
    private Map<String, Object> data;

    /**
     * 命令字符串，大小限制2KB
     */
    private String args;

}
