package net.javase.onenet.model.base;

import cn.hutool.core.util.StrUtil;
import net.javase.onenet.annotation.ApiParam;

import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.Map;

/**
 * BaseModel
 *
 * @author Frank
 */
public class BaseModel {

    /**
     * This To Map
     *
     * @return {@link Map}
     */
    public Map<String, Object> toMap() {
        Map<String, Object> map = new HashMap<>();
        Field[] fields = this.getClass().getDeclaredFields();
        for (Field field : fields) {
            Object obj;
            try {
                field.setAccessible(true);
                obj = field.get(this);
                if (obj != null) {
                    ApiParam apiParam = field.getAnnotation(ApiParam.class);
                    if (apiParam != null) {
                        if (apiParam.ignore()) {
                            continue;
                        }
                        if (StrUtil.isNotBlank(apiParam.name())) {
                            map.put(apiParam.name(), obj);
                            continue;
                        }
                    }
                    map.put(field.getName(), obj);
                }
            } catch (IllegalArgumentException | IllegalAccessException e) {
                e.printStackTrace();
            }
        }
        return map;
    }

    /**
     * 获取参数map
     *
     * @return Map
     */
    public Map<String, Map<String, Object>> paramsMap() {
        Map<String, Map<String, Object>> params = new HashMap<>((int) ((2 / 0.75f) + 1));
        Map<String, Object> bodyMap = new HashMap<>();
        Map<String, Object> queryMap = new HashMap<>();
        Field[] fields = this.getClass().getDeclaredFields();
        for (Field field : fields) {
            Object obj;
            try {
                field.setAccessible(true);
                obj = field.get(this);
                if (obj != null) {
                    ApiParam apiParam = field.getAnnotation(ApiParam.class);
                    if (apiParam != null) {
                        if (apiParam.ignore()) {
                            continue;
                        }
                        if (StrUtil.isNotBlank(apiParam.name())) {
                            if (apiParam.isQuery()) {
                                queryMap.put(apiParam.name(), obj);
                            } else {
                                bodyMap.put(apiParam.name(), obj);
                            }
                        } else {
                            if (apiParam.isQuery()) {
                                queryMap.put(field.getName(), obj);
                            } else {
                                bodyMap.put(field.getName(), obj);
                            }
                        }
                    } else {
                        bodyMap.put(field.getName(), obj);
                    }
                }
            } catch (IllegalArgumentException | IllegalAccessException e) {
                e.printStackTrace();
            }
        }
        params.put("body", bodyMap);
        params.put("query", queryMap);
        return params;
    }


}
